import { PublicKey } from '@metaplex-foundation/umi';
import { NftGate, NftGateArgs } from '../generated';
import { GuardManifest } from '../guards';
/**
 * The nftGate guard restricts minting to holders
 * of a specified NFT collection.
 *
 * This means the mint address of an NFT from this
 * collection must be passed when minting.
 */
export declare const nftGateGuardManifest: GuardManifest<NftGateArgs, NftGate, NftGateMintArgs>;
export declare type NftGateMintArgs = {
    /**
     * The mint address of an NFT from the required
     * collection that belongs to the payer.
     */
    mint: PublicKey;
    /**
     * The token account linking the NFT with its owner.
     *
     * @defaultValue
     * Defaults to the associated token address using the
     * mint address of the NFT and the payer's address.
     */
    tokenAccount?: PublicKey;
};
